==> plasma-remotecontrollers_5.27.5.orig.tar.xz: plasma-remotecontrollers-5.27.5/org.kde.plasma-remotecontrollers.desktop.cmake <==
# SPDX-License-Identifier: CC0-1.0
# SPDX-FileCopyrightText: 2022 Bart Ribbers <bribbers@disroot.org>
[Desktop Entry]
Name=Plasma Remotecontrollers
Name[ar]=متحكم عن بعد لبلازما
Name[ca]=Controls remots del Plasma
Name[ca@valencia]=Controls remots de Plasma
Name[de]=Plasma-Fernbedienungen
Name[en_GB]=Plasma Remotecontrollers
Name[es]=Controladores remotos de Plasma
Name[eu]=Plasmaren urruneko aginteak
Name[fi]=Plasma-kaukosäätimet
Name[fr]=Contrôleurs distants de Plasma
Name[hu]=Plasma távirányítók
Name[ia]=Controlatores remote de Plasma
Name[it]=Plasma Remotecontrollers
Name[ka]=Plasma Remotecontrollers
Name[ko]=Plasma 리모콘
Name[nl]=Plasma afstandsbedieningen
Name[nn]=Fjernkontrollar for Plasma
Name[pl]=Kontrolery Plazmy
Name[pt]=Comandos à Distância do Plasma
Name[ru]=Управление контроллерами
Name[sk]=Diaľkové ovládače Plasma
Name[sl]=Plasma Remotecontrollers
Name[sv]=Plasma fjärrkontroller
Name[tr]=Plasma Uzaktan Kumandalar
Name[uk]=Дистанційне керування Плазмою
Name[x-test]=xxPlasma Remotecontrollersxx
Name[zh_CN]=Plasma 无线控制器
Name[zh_TW]=Plasma Remotecontrollers
Comment=Translates events from various input devices to native key presses
Comment[ar]=يترجم الأحداث من أجهزة الإدخال المختلفة إلى كبسات مفاتيح أصلية
Comment[ca]=Tradueix esdeveniments des de diversos dispositius d'entrada a pulsacions natives de tecles
Comment[ca@valencia]=Traduïx esdeveniments des de diversos dispositius d'entrada a pulsacions natives de tecles
Comment[de]=Ereignisse von verschiedenen Eingabegeräten werden in systemeigene Tastendrücke übersetzt
Comment[en_GB]=Translates events from various input devices to native key presses
Comment[es]=Traduce eventos de diversos dispositivos de entrada a pulsaciones de teclas nativas
Comment[eu]=Hainbat sarrerako gailuren gertaerak berezko tekla-sakatzeetara itzultzen ditu
Comment[fi]=Muuttaa eri syötelaitteiden tapahtumat näppäinpainalluksiksi
Comment[fr]=Traduit les évènements à partir de divers périphériques d'entrée en des appuis natifs de touches
Comment[hu]=A különböző beviteli eszközökről érkező eseményeket lefordítása natív billentyűleütésekké
Comment[ia]=Traduce eventos ex varie dispositivo de egresso a pressiones de clave native
Comment[it]=Traduce gli eventi da vari dispositivi di immissione in pressioni di tasti nativi
Comment[ka]=შეყვანის სხვადასხვა მოწყობილობებიდან მოსული სიგნალის ჩვეულებრივ ღილაკებში თარგმნა
Comment[ko]=다양한 입력 장치 이벤트를 키 입력으로 전환
Comment[nl]=Vertaalt gebeurtenissen uit verschillende invoerapparaten naar inheemse toetsaanslagen
Comment[nn]=Gjer om hendingar sende frå ulike inn-einingar om til tastetrykk
Comment[pl]=Tłumaczy zdarzenia z różnych urządzeń wejściowych na naciśnięcia klawiszy
Comment[pt]=Traduz eventos de vários dispositivos remotos para sequências de teclas nativas
Comment[ru]=Преобразование событий, получаемых с различных устройств, в нажатия клавиш
Comment[sk]=Prekladá udalosti z rôznych vstupných zariadení na natívne stlačenia kláves
Comment[sl]=Prevaja dogodke iz različnih vhodnih naprav v pritiske domorodnih tipk
Comment[sv]=Översätter händelser från olika typer av inmatningsenheter till inbyggda tangentnedtryckningar
Comment[tr]=Çeşitli giriş aygıtlarından alınan olayları yerel düğme basımlarına çevirir
Comment[uk]=Транслює події з різних пристроїв введення у сигнали про натискання клавіш
Comment[x-test]=xxTranslates events from various input devices to native key pressesxx
Comment[zh_CN]=将各种输入设备的事件翻译为系统原生按键事件
Comment[zh_TW]=將各種輸入裝置來的事件翻譯成原生的按鍵事件
Exec=@CMAKE_INSTALL_PREFIX@/bin/plasma-remotecontrollers
Icon=gamepad
Type=Application
X-KDE-PluginInfo-Version=@PROJECT_VERSION@
NoDisplay=true
X-KDE-Wayland-Interfaces=org_kde_kwin_fake_input,org_kde_plasma_window_management

==> plasma-remotecontrollers-5.27.8.tar.xz: plasma-remotecontrollers-5.27.8/org.kde.plasma-remotecontrollers.desktop.cmake <==
# SPDX-License-Identifier: CC0-1.0
# SPDX-FileCopyrightText: 2022 Bart Ribbers <bribbers@disroot.org>
[Desktop Entry]
Name=Plasma Remotecontrollers
Name[ar]=متحكم عن بعد لبلازما
Name[ca]=Controls remots del Plasma
Name[ca@valencia]=Controls remots de Plasma
Name[de]=Plasma-Fernbedienungen
Name[en_GB]=Plasma Remotecontrollers
Name[es]=Controladores remotos de Plasma
Name[eu]=Plasmaren urruneko aginteak
Name[fi]=Plasma-kaukosäätimet
Name[fr]=Contrôleurs distants de Plasma
Name[gl]=Mandos a distancia de Plasma
Name[hu]=Plasma távirányítók
Name[ia]=Controlatores remote de Plasma
Name[it]=Plasma Remotecontrollers
Name[ka]=Plasma Remotecontrollers
Name[ko]=Plasma 리모콘
Name[nl]=Plasma afstandsbedieningen
Name[nn]=Fjernkontrollar for Plasma
Name[pl]=Kontrolery Plazmy
Name[pt]=Comandos à Distância do Plasma
Name[ru]=Управление контроллерами
Name[sk]=Diaľkové ovládače Plasma
Name[sl]=Plasma Remotecontrollers
Name[sv]=Plasma fjärrkontroller
Name[tr]=Plasma Uzaktan Kumandalar
Name[uk]=Дистанційне керування Плазмою
Name[x-test]=xxPlasma Remotecontrollersxx
Name[zh_CN]=Plasma 无线控制器
Name[zh_TW]=Plasma Remotecontrollers
Comment=Translates events from various input devices to native key presses
Comment[ar]=يترجم الأحداث من أجهزة الإدخال المختلفة إلى كبسات مفاتيح أصلية
Comment[ca]=Tradueix esdeveniments des de diversos dispositius d'entrada a pulsacions natives de tecles
Comment[ca@valencia]=Traduïx esdeveniments des de diversos dispositius d'entrada a pulsacions natives de tecles
Comment[de]=Ereignisse von verschiedenen Eingabegeräten werden in systemeigene Tastendrücke übersetzt
Comment[en_GB]=Translates events from various input devices to native key presses
Comment[es]=Traduce eventos de diversos dispositivos de entrada a pulsaciones de teclas nativas
Comment[eu]=Hainbat sarrerako gailuren gertaerak berezko tekla-sakatzeetara itzultzen ditu
Comment[fi]=Muuttaa eri syötelaitteiden tapahtumat näppäinpainalluksiksi
Comment[fr]=Traduit les évènements à partir de divers périphériques d'entrée en des appuis natifs de touches
Comment[gl]=Traduce eventos de varios dispositivos de entrada a premas de tecla nativas.
Comment[hu]=A különböző beviteli eszközökről érkező eseményeket lefordítása natív billentyűleütésekké
Comment[ia]=Traduce eventos ex varie dispositivo de egresso a pressiones de clave native
Comment[it]=Traduce gli eventi da vari dispositivi di immissione in pressioni di tasti nativi
Comment[ka]=შეყვანის სხვადასხვა მოწყობილობებიდან მოსული სიგნალის ჩვეულებრივ ღილაკებში თარგმნა
Comment[ko]=다양한 입력 장치 이벤트를 키 입력으로 전환
Comment[nl]=Vertaalt gebeurtenissen uit verschillende invoerapparaten naar inheemse toetsaanslagen
Comment[nn]=Gjer om hendingar sende frå ulike inn-einingar om til tastetrykk
Comment[pl]=Tłumaczy zdarzenia z różnych urządzeń wejściowych na naciśnięcia klawiszy
Comment[pt]=Traduz eventos de vários dispositivos remotos para sequências de teclas nativas
Comment[ru]=Преобразование событий, получаемых с различных устройств, в нажатия клавиш
Comment[sk]=Prekladá udalosti z rôznych vstupných zariadení na natívne stlačenia kláves
Comment[sl]=Prevaja dogodke iz različnih vhodnih naprav v pritiske domorodnih tipk
Comment[sv]=Översätter händelser från olika typer av inmatningsenheter till inbyggda tangentnedtryckningar
Comment[tr]=Çeşitli giriş aygıtlarından alınan olayları yerel düğme basımlarına çevirir
Comment[uk]=Транслює події з різних пристроїв введення у сигнали про натискання клавіш
Comment[x-test]=xxTranslates events from various input devices to native key pressesxx
Comment[zh_CN]=将各种输入设备的事件翻译为系统原生按键事件
Comment[zh_TW]=將各種輸入裝置來的事件翻譯成原生的按鍵事件
Exec=@CMAKE_INSTALL_PREFIX@/bin/plasma-remotecontrollers
Icon=gamepad
Type=Application
X-KDE-PluginInfo-Version=@PROJECT_VERSION@
NoDisplay=true
X-KDE-Wayland-Interfaces=org_kde_kwin_fake_input,org_kde_plasma_window_management
